@@ -1,6 +1,7 @@
 
 //! Module for Variability semantic analysis.
 
+use std::fmt;
 use crate::logic::descriptor::{VariabilityDescriptor};
 
 /// Enum for variability identification.
@@ -29,3 +30,12 @@ impl Variability {
         }
     }
 }
+
+impl fmt::Display for Variability {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}", match self {
+            Variability::Const  => "const",
+            Variability::Var    => "var",
+        })
+    }
+}
